==> deepin-camera_1.0.0.15.orig.tar.xz: deepin-camera-1.0.0.15/src/translations/deepin-camera_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu" version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>A videó rögzítése folyamatban van. Bezárja az ablakot?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Mappa megnyitása</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Mappa megnyitása</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Nincs jogosultsága az adott mappa kezelésére</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation>Érvénytelen mappa</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Mappa megnyitása</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Alap</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Fájl elérési útvonala</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Fényképezés</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Folyamatos üzemmód</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Önkioldó késleltetése</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Kimenet</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Kimeneti formátum</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 db.</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 db.</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>A Kamera egy kép és videofelvételi segédprogram, amely a számítógép kameráját vagy webkameráját használja.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>A fájl mentése sikertelen</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Mentés ide:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Fénykép:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Videó:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Felbontási beállítások</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Felbontás:</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>Fénykép készítése</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Videó rögzítése</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Fénykép készítés megállítása</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Nem található Webkamera</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>A Webkamera használatban van</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Rögzítés megállítása</translation>
    </message>
</context>
</TS>

==> deepin-camera_1.1.2.orig.tar.xz: deepin-camera-1.1.2/src/translations/deepin-camera_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>A videó rögzítése folyamatban van. Bezárja az ablakot?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Mappa megnyitása</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Mappa megnyitása</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Nyomtatás</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Nincs jogosultsága az adott mappa kezelésére</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Érvénytelen mappa</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Mappa megnyitása</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Alapvető</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Fájl elérési útvonala</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Fényképezés</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Folyamatos üzemmód</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Önkioldó késleltetése</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Kimenet</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Kimeneti formátum</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 db.</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 db.</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>A Kamera egy kép és videofelvételi segédprogram, amely a számítógép kameráját vagy webkameráját használja.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>A fájl mentése sikertelen</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Mentés ide:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Fénykép:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Videó:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Felbontási beállítások</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Felbontás:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Fényképek:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Videók:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Hang effektek</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Rögzítés megállítása</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Nyomtatás</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Segítség</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Gyorsbillentyűk megjelenítése</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Fénykép készítés megállítása</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Helyi menü</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>Fénykép készítése</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Videó rögzítése</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Fénykép készítés megállítása</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Nem található Webkamera</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>A Webkamera használatban van</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Rögzítés megállítása</translation>
    </message>
</context>
</TS>
